searchData={"items":[{"type":"module","title":"Criterion","doc":"A frame work to write unit tests as a list of steps. It can be used to write tests BDD style.","ref":"Criterion.html"},{"type":"module","title":"Usage - Criterion","doc":"1. Define scenarios using the `scenario/2` macro.\n2. Inside each scenario, define steps using the `step/2` macro.\n3. Steps can be either plain steps or steps with context variables.\n4. Shared steps can be defined external to the scenario","ref":"Criterion.html#module-usage"},{"type":"module","title":"Example - Criterion","doc":"```elixir\n# Define a scenario\nstep \"Shared\", context do\n  context\nend\n\nscenario \"Adding numbers\" do\n  # Use a shared step\n  step \"Shared\"\n  # Define a step\n  step \"Addition\" do\n    assert 1 + 1 == 2\n  end\n\n\n\n  # Define a step with context\n  step \"Addition with context\", context do\n    result = context[:a] + context[:b]\n    assert result == 5\n  end\nend\n```","ref":"Criterion.html#module-example"},{"type":"macro","title":"Criterion.feature/2","doc":"","ref":"Criterion.html#feature/2"},{"type":"macro","title":"Criterion.scenario/3","doc":"","ref":"Criterion.html#scenario/3"},{"type":"macro","title":"Criterion.step/3","doc":"","ref":"Criterion.html#step/3"},{"type":"task","title":"mix criterion.gen.features","doc":"This Mix task scans the project for tests written using the `Criterion` module and generates\ncorresponding feature files in *Gherkin* syntax.","ref":"Mix.Tasks.Criterion.Gen.Features.html"},{"type":"task","title":"Usage - mix criterion.gen.features","doc":"```\nmix criterion.gen.features --dir  \n```","ref":"Mix.Tasks.Criterion.Gen.Features.html#module-usage"},{"type":"task","title":"Options - mix criterion.gen.features","doc":"- `--output` - specify the directory to generate feature files in. default is `test/features`\n\nThe task will create the specified directory (default is `features`) and generate a `.feature` file for each test file\nin your project, converting the Criterion tests into Gherkin syntax.","ref":"Mix.Tasks.Criterion.Gen.Features.html#module-options"},{"type":"function","title":"Mix.Tasks.Criterion.Gen.Features.run/1","doc":"","ref":"Mix.Tasks.Criterion.Gen.Features.html#run/1"},{"type":"task","title":"mix criterion.gen.tests","doc":"This Mix task reads Gherkin feature files and generates corresponding test files using the Criterion module.","ref":"Mix.Tasks.Criterion.Gen.Tests.html"},{"type":"task","title":"Usage - mix criterion.gen.tests","doc":"```\nmix criterion.gen.tests\n```","ref":"Mix.Tasks.Criterion.Gen.Tests.html#module-usage"},{"type":"task","title":"Options - mix criterion.gen.tests","doc":"- `--dir` - specify the directory to read feature files from. default is `test/features`\n- `--file` - to generate test for a list of files\n- `--output` - specify the directory to generate the test files in. default is `test/features`","ref":"Mix.Tasks.Criterion.Gen.Tests.html#module-options"},{"type":"function","title":"Mix.Tasks.Criterion.Gen.Tests.run/1","doc":"","ref":"Mix.Tasks.Criterion.Gen.Tests.html#run/1"},{"type":"extras","title":"Criterion","doc":"# Criterion\n\nA library to write ExUnit tests BDD style","ref":"readme.html"},{"type":"extras","title":"Installation - Criterion","doc":"The package can be installed\nby adding `criterion` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:criterion, \"~> 0.1.0\", only: [:test]}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Criterion","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Shared steps - Criterion","doc":"```elixir\ndefmodule Criterion.SharedSteps do\n  import Criterion\n\n  step \"Given a number\", _context do\n    %{number: :rand.uniform(100)}\n  end\nend\n```","ref":"readme.html#shared-steps"},{"type":"extras","title":"Test - Criterion","doc":"```elixir\ndefmodule CriterionTest do\n  use ExUnit.Case\n  import Criterion\n  import Criterion.SharedSteps\n\n  feature \"Math\" do\n    scenario \"Square\" do\n      step(\"Given a number\")\n\n      step \"When the number is multiplied by it self\", %{number: number} do\n        result = number * number\n        %{result: result}\n      end\n\n      step \"Then the result is greater than the number\", %{result: result, number: number} do\n        assert result > number\n      end\n    end\n  end\nend\n```","ref":"readme.html#test"},{"type":"extras","title":"Generating feature files - Criterion","doc":"```\nmix criterion.gen.features\n```\n\n#### Options\n\n- `--output` - specify the directory to generate feature files in. default is `test/features`","ref":"readme.html#generating-feature-files"},{"type":"extras","title":"Generating test files - Criterion","doc":"```\nmix criterion.gen.tests\n```\n\n#### Options\n\n- `--dir` - specify the directory to read feature files from. default is `test/features`\n- `--file` - to generate test for a list of files\n- `--output` - specify the directory to generate the test files in. default is `test/features`","ref":"readme.html#generating-test-files"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}